==> abtransfers_0.0.3.0.orig.tar.bz2: abtransfers-0.0.3.0/src/abt_empfaengerinfo.cpp <==
/******************************************************************************
 * Copyright (C) 2011 Patrick Wacker
 * This program is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the Free
 * Software Foundation; either version 2 of the License, or (at your option)
 * any later version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for
 * more details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program; if not, write to the Free Software Foundation, Inc., 59 Temple
 * Place, Suite 330, Boston, MA 02111-1307, USA.
 ******************************************************************************
 * Dont forget: svn propset svn:keywords "Date Author Rev HeadURL" filename
 ******************************************************************************
 * $HeadURL: http://schmufu.dyndns.org/svn/ab_transfers/tags/0.0.3.0/src/abt_empfaengerinfo.cpp $
 * $Author: Patrick Wacker $
 * $Date: 2012-02-09 18:43:17 +0100 (Thu, 09 Feb 2012) $
 * $Rev: 164 $
 *
 * description:
 *
 *
 * changes not documented here, see svn
 *
 ******************************************************************************/

#include "abt_empfaengerinfo.h"

abt_EmpfaengerInfo::abt_EmpfaengerInfo()
{

}

abt_EmpfaengerInfo::abt_EmpfaengerInfo(QString &Name, QString &Kontonummer,
					   QString &BLZ, QString Verw1,
					   QString Verw2, QString Verw3,
					   QString Verw4):
	m_Name(Name),
	m_Kontonummer(Kontonummer),
	m_Bankleitzahl(BLZ),
	m_Verw1(Verw1),	m_Verw2(Verw2), m_Verw3(Verw3), m_Verw4(Verw4)
{

}

abt_EmpfaengerInfo::~abt_EmpfaengerInfo()
{

}

bool abt_EmpfaengerInfo::operator ==(const abt_EmpfaengerInfo& e) const
{
	//Ein Empfänger wird anhand der Kontonummer und BLZ identifiziert, wenn
	//diese beiden gleich sind handelt es sich um ein und denselben
	//Empfänger
	return (this->getKontonummer() == e.getKontonummer()) &&
		(this->getBLZ() == e.getBLZ());

}

==> abtransfers_0.0.4.1.orig.tar.bz2: abtransfers-0.0.4.1/src/abt_empfaengerinfo.cpp <==
/******************************************************************************
 * Copyright (C) 2011 Patrick Wacker
 * This program is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the Free
 * Software Foundation; either version 2 of the License, or (at your option)
 * any later version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for
 * more details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program; if not, write to the Free Software Foundation, Inc., 59 Temple
 * Place, Suite 330, Boston, MA 02111-1307, USA.
 ******************************************************************************
 * Dont forget: svn propset svn:keywords "Date Author Rev HeadURL" filename
 ******************************************************************************
 * $HeadURL: http://schmufu.dyndns.org/svn/ab_transfers/tags/0.0.4.1/src/abt_empfaengerinfo.cpp $
 * $Author: Patrick Wacker $
 * $Date: 2013-02-26 21:28:42 +0100 (Tue, 26 Feb 2013) $
 * $Rev: 359 $
 *
 * description:
 *
 *
 * changes not documented here, see svn
 *
 ******************************************************************************/

#include "abt_empfaengerinfo.h"

abt_EmpfaengerInfo::abt_EmpfaengerInfo()
{

}

abt_EmpfaengerInfo::abt_EmpfaengerInfo(const QString &Name,
				       const QString &Kontonummer,
				       const QString &BLZ,
				       const QString &IBAN,
				       const QString &BIC,
				       const QString &Institut,
				       const QString &Verw):
	m_Name(Name),
	m_Kontonummer(Kontonummer),
	m_Bankleitzahl(BLZ),
	m_IBAN(IBAN),
	m_BIC(BIC),
	m_Institut(Institut),
	m_Verw(Verw)
{

}

abt_EmpfaengerInfo::~abt_EmpfaengerInfo()
{

}

bool abt_EmpfaengerInfo::operator ==(const abt_EmpfaengerInfo& e) const
{
	//A recipient is identified by the account number and Bankcode or
	//by the IBAN and BIC if one of this pairs are identical, the
	//recipients are the same.
	return (((this->getKontonummer() == e.getKontonummer()) &&
		 (this->getBLZ() == e.getBLZ())) ||
		((this->getIBAN() == e.getIBAN()) &&
		 (this->getBIC() == e.getBIC())));
}
